#
# spec file for package sane-airscan
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sane-airscan
Version:        0.99.34
Release:        1.1
Summary:        Universal driver for Apple AirScan (eSCL) and WSD
License:        SUSE-GPL-2.0+-with-sane-exception
URL:            https://github.com/alexpevzner/sane-airscan
Source0:        %{name}-%{version}.tar.zst
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  zstd
BuildRequires:  pkgconfig(avahi-core)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sane-backends)
Provides:       lib%{name}1 = %{version}
Obsoletes:      lib%{name}1 < %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description
This package contains a SANE backend for MFP and document scanners that
implements either eSCL (AirScan/AirPrint scanning) or WSD "driverless"
scanning protocol

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
rm %{buildroot}%{_libdir}/sane/libsane-airscan.so

%files
%license LICENSE COPYING
%doc README.md
%{_bindir}/airscan-discover
%config(noreplace) %{_sysconfdir}/sane.d/airscan.conf
%config %{_sysconfdir}/sane.d/dll.d/airscan
%{_libdir}/sane/libsane-airscan.so.1
%{_mandir}/man?/{sane-airscan,airscan-discover}.?%{?ext_man}
%if 0%{?suse_version} == 1500
%dir %{_sysconfdir}/sane.d/dll.d
%endif

%changelog
* Wed Apr 16 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 0.99.34:
  * eSCL quirks for Xerox B205/B215
  * Add Brother MFC-L3740CDWE to support list
* Mon Mar 17 2025 rrahl0@opensuse.org
- Update to version 0.99.33:
  * WSD: fixed "scan-intent" option handling on ADF Duplex source
  * eSCL: support both forms, scan:SupportedIntent and scan:Intent in capabilities
* Sat Feb  1 2025 rrahl0@opensuse.org
- Update to version 0.99.32:
  * docs: Add Brother ADS-4300N
  * Added the "pretend-local" configuration option to treat networked scanners
    as if they were locally attached
  * sane-airscan.5 is automatically generated from sane-aircan.5.md
* Mon Dec 30 2024 rrahl0@opensuse.org
- Update to version 0.99.31:
  * eSCL: rollback of the previous change (quirk_adf_max_pages)
  * eSCL: added quirk_adf_max_pages
  * Cosmetic (fixed typo in a commend)
  * HTTP timeout for "short" requests extended from 5s to 20s
  * The "sane-intent" option cannot be SANE_CAP_INACTIVE
  * WSD: workaround for ADF Duplex on Brother MFC-9370CDW
  * WSD: cosmetic
  * eSCL: delay between subsequent loads made Brother-specific
  * Update README.md: updated Gentoo support status
* Fri Nov 22 2024 Richard Rahl <rrahl0@opensuse.org>
- do not replace config (as configured scanners are saved to that file)
* Tue Nov 19 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.99.30:
  * WSD: sca:ScannerDescription requested in sca:GetScannerElementsRequest
  * WSD: Ricoh Aficio MP 201: fixed detection of "ADF empty" state
  * HTTP: logged "end of input" event
  * test-decode: more informative usage when invoked without args
  * test-devcaps: stub implementation
  * test-devcaps: works for WSD
  * WSD: fixed ADF duplex on Epson Workforce WF-3520
  * test-devcaps: works for eSCL too
  * Device model name propagated from zeroconf to proto handlers, for quirks
  * WSD: fix for ADF scan on RICOH Aficio MP 201
  * WSD: more information requested in sca:GetScannerElementsRequest
  * Some devices don't behave if sca:ImagesToTransfer isn't set as expected.
  * README: fixed OKI supported table entries
  * OKI-MB471/OKI-MC332dn/OKI-MC362dn marked as not supporting eSCL
  * Dell E514dw added to the list
  * Kyocera TASKalfa 3051ci added to the list
  * doc: add Epson ET-2650 series
  * Add EPSON WF-2760 Series
  * WSD: Add content type selection
  * eSCL: Add scan intent selection
  * Fixed logging of supported/chosen scan intent
  * eSCL: fixed parsing of the supported scan intents in the device capabilities
  * ID_SCANINTENT better documented
  * Tweaked a textual description of the scan-intent option
  * SANE name for ID_SCANINTENT_DOCUMENT now "Document" (was "Text")
  * Added ID_SCANINTENT_UNSET value for the 'sane-intent'
  * Setting "scan-intent" now requires a precise match.
  * eSCL: delay between subsequent loads made Brother-specific
  * WSD: cosmetic
  * WSD: workaround for ADF Duplex on Brother MFC-9370CDW
  * The "sane-intent" option cannot be SANE_CAP_INACTIVE
- fix obsoleting itself
* Tue Jun  4 2024 Richard Rahl <rrahl0@disroot.org>
- final adjustment for Obsoletes
* Tue Jun  4 2024 Richard Rahl <rrahl0@disroot.org>
- add Provides and Obsoletes for old packages
* Mon Jun  3 2024 Richard Rahl <rrahl0@disroot.org>
- remove code which related to the old packaging
* Mon Jun  3 2024 Richard Rahl <rrahl0@disroot.org>
- adapt packaging according to
  https://build.opensuse.org/request/show/1177729#comment-1944225
  (remove .so file and include the libsane-airscan.so.1 in the main
  package
* Thu May 30 2024 Richard Rahl <rrahl0@disroot.org>
- add runtime dependency
* Fri Mar 15 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
